==> xoonips-3.41.zip: xoonips-3.41/itemtypes/xnpmemo/language/english/main.php <==
<?php
// $Revision: 1.1.12.3 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 * $Revision: 1.1.12.3 $
 */

// _MD_<MODULENAME>_<STRINGNAME>

define( "_MD_XNPMEMO_ITEM_LINK_LABEL", "Item Link" );
define( "_MD_XNPMEMO_MEMO_FILE_LABEL", "Memo File" );

define( "_MD_XNPMEMO_EXPLANATION", "Personal Memo Pad." );

define( '_MD_XNPMEMO_XMLRPC_DISPLAY_NAME_MEMO_ID'   , 'Item ID' );
define( '_MD_XNPMEMO_XMLRPC_DISPLAY_NAME_ITEM_LINK' , 'Item Link' );
define( '_MD_XNPMEMO_XMLRPC_DISPLAY_NAME_MEMO_FILE' , 'Memo File' );

?>

==> xoonips-3.49.zip: xoonips-3.49/itemtypes/xnpmemo/language/english/main.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 */

// _MD_<MODULENAME>_<STRINGNAME>

define('_MD_XNPMEMO_ITEM_LINK_LABEL', 'Item Link');
define('_MD_XNPMEMO_MEMO_FILE_LABEL', 'Memo File');

define('_MD_XNPMEMO_EXPLANATION', 'Personal Memo Pad.');

define('_MD_XNPMEMO_XMLRPC_DISPLAY_NAME_MEMO_ID', 'Item ID');
define('_MD_XNPMEMO_XMLRPC_DISPLAY_NAME_ITEM_LINK', 'Item Link');
define('_MD_XNPMEMO_XMLRPC_DISPLAY_NAME_MEMO_FILE', 'Memo File');
